__author__ = "sandyzikun"
__version__ = "0.0.7"
from . import datasets, fourier
from . import hmm
from . import ae
from . import heartland
print("あなたもミクと創ろう、世界を繋ごう。")